==> gnustep-gui_0.9.5.orig.tar.gz: gnustep-gui-0.9.5.orig/Headers/Additions/GNUstepGUI/GSTitleView.h <==
/** <title>GSTitleView</title>

   Copyright (C) 2003 Free Software Foundation, Inc.

   Author: Serg Stoyan <stoyan@on.com.ua>
   Date:   Mar 2003
   
   This file is part of the GNUstep GUI Library.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with this library; see the file COPYING.LIB.
   If not, write to the Free Software Foundation,
   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef _GNUstep_H_GSTitleView
#define _GNUstep_H_GSTitleView

#include <AppKit/NSView.h>

@class NSMutableDictionary;
@class NSButton;
@class NSImage;

@interface GSTitleView : NSView
{
  NSButton            *closeButton;
  NSButton            *miniaturizeButton;
  NSMutableDictionary *textAttributes;
  NSColor             *titleColor;

  @private
    id       _owner;
    unsigned _ownedByMenu;
    unsigned _hasCloseButton;
    unsigned _hasMiniaturizeButton;
    unsigned _isKeyWindow;
    unsigned _isMainWindow;
    unsigned _isActiveApplication;
}

// ============================================================================
// ==== Initialization & deallocation
// ============================================================================

+ (float) height;
- (void) setOwner: (id)owner;
- (id) initWithOwner: (id)owner;
- (id) owner;
- (NSSize) titleSize;

// ============================================================================
// ==== Buttons
// ============================================================================

- (void) addCloseButtonWithAction: (SEL)closeAction;
- (NSButton *) closeButton;
- (void) removeCloseButton;
- (void) addMiniaturizeButtonWithAction: (SEL)miniaturizeAction;
- (NSButton *)miniaturizeButton;
- (void) removeMiniaturizeButton;

@end

#endif

==> gnustep-gui_0.12.0.orig.tar.gz: gnustep-gui-0.12.0/Headers/Additions/GNUstepGUI/GSTitleView.h <==
/** <title>GSTitleView</title>

   Copyright (C) 2003 Free Software Foundation, Inc.

   Author: Serg Stoyan <stoyan@on.com.ua>
   Date:   Mar 2003
   
   This file is part of the GNUstep GUI Library.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with this library; see the file COPYING.LIB.
   If not, write to the Free Software Foundation,
   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#ifndef _GNUstep_H_GSTitleView
#define _GNUstep_H_GSTitleView

#include <AppKit/NSView.h>

@class NSMutableDictionary;
@class NSButton;
@class NSImage;

@interface GSTitleView : NSView
{
  NSButton            *closeButton;
  NSButton            *miniaturizeButton;
  NSMutableDictionary *textAttributes;
  NSColor             *titleColor;

  @private
    id       _owner;
    unsigned _ownedByMenu;
    unsigned _hasCloseButton;
    unsigned _hasMiniaturizeButton;
    unsigned _isKeyWindow;
    unsigned _isMainWindow;
    unsigned _isActiveApplication;
}

// ============================================================================
// ==== Initialization & deallocation
// ============================================================================

+ (float) height;
- (void) setOwner: (id)owner;
- (id) initWithOwner: (id)owner;
- (id) owner;
- (NSSize) titleSize;

// ============================================================================
// ==== Buttons
// ============================================================================

- (void) addCloseButtonWithAction: (SEL)closeAction;
- (NSButton *) closeButton;
- (void) removeCloseButton;
- (void) addMiniaturizeButtonWithAction: (SEL)miniaturizeAction;
- (NSButton *)miniaturizeButton;
- (void) removeMiniaturizeButton;

@end

#endif
